from .australia import (
    Australia,
    AustralianCapitalTerritory,
    NewSouthWales,
    NorthernTerritory,
    Queensland,
    SouthAustralia,
    Tasmania,
    Hobart,
    Victoria,
    WesternAustralia
)
from .marshall_islands import MarshallIslands
from .new_zealand import NewZealand


__all__ = (
    # Australia and al.
    'Australia',
    'AustralianCapitalTerritory',
    'NewSouthWales',
    'NorthernTerritory',
    'Queensland',
    'SouthAustralia',
    'Tasmania',
    'Hobart',
    'Victoria',
    'WesternAustralia',
    # Other oceanian countries
    'MarshallIslands',
    'NewZealand',
)
